@@ -89,7 +89,7 @@ QString RTF2HTML::toHTML() const {
             {
                std::string stmp(1,*buf_in++);
                stmp+=*buf_in++;
-               int code=std::strtol(stmp.c_str(), NULL, 16);
+               long int code=std::strtol(stmp.c_str(), NULL, 16);
                switch (code)
                {
                   case 167:
@@ -198,7 +198,7 @@ QString RTF2HTML::toHTML() const {
                case rtf_keyword::rkw_fonttbl:
                {
                   font fnt;
-                  int font_num;
+                  int font_num=0;
                   bool full_name=false;
                   bool in_font=false;
                   while (! (*buf_in=='}' && !in_font))
