@@ -38,6 +38,7 @@
 #include "core/tellico_config.h"
 #include "images/imagefactory.h"
 #include "gui/combobox.h"
+#include "gui/collectiontypecombo.h"
 #include "gui/previewdialog.h"
 #include "newstuff/manager.h"
 #include "fieldformat.h"
@@ -58,7 +59,12 @@
 #include <kapplication.h>
 #include <kvbox.h>
 #include <khbox.h>
+
+#ifdef ENABLE_KNEWSTUFF3
+#include <KNS3/DownloadDialog>
+#else
 #include <KNS/Engine>
+#endif
 
 #include <QSize>
 #include <QLayout>
@@ -628,6 +634,20 @@ void ConfigDialog::initFetchPage(QFrame* frame) {
   m_moveDownSourceBtn->setWhatsThis(i18n("The order of the data sources sets the order "
                                          "that Tellico uses when entries are automatically updated."));
 
+  KHBox* hb2 = new KHBox(frame);
+  leftLayout->addWidget(hb2);
+  m_cbFilterSource = new QCheckBox(i18n("Filter by type:"), hb2);
+  connect(m_cbFilterSource, SIGNAL(clicked()), SLOT(slotSourceFilterChanged()));
+  m_sourceTypeCombo = new GUI::CollectionTypeCombo(hb2);
+  connect(m_sourceTypeCombo, SIGNAL(currentIndexChanged(int)), SLOT(slotSourceFilterChanged()));
+  // we want to remove the item for a custom collection
+  int index = m_sourceTypeCombo->findData(Data::Collection::Base);
+  if(index > -1) {
+    m_sourceTypeCombo->removeItem(index);
+  }
+  // disable until check box is checked
+  m_sourceTypeCombo->setEnabled(false);
+
   // these icons are rather arbitrary, but seem to vaguely fit
   QVBoxLayout* vlay = new QVBoxLayout();
   l->addLayout(vlay);
@@ -739,9 +759,11 @@ void ConfigDialog::readFetchConfig() {
   m_sourceListWidget->clear();
   m_configWidgets.clear();
 
+  m_sourceListWidget->setUpdatesEnabled(false);
   Fetch::FetcherVec fetchers = Fetch::Manager::self()->fetchers();
   foreach(Fetch::Fetcher::Ptr fetcher, fetchers) {
-    GeneralFetcherInfo info(fetcher->type(), fetcher->source(), fetcher->updateOverwrite());
+    GeneralFetcherInfo info(fetcher->type(), fetcher->source(),
+                            fetcher->updateOverwrite(), fetcher->uuid());
     SourceListItem* item = new SourceListItem(m_sourceListWidget, info);
     item->setFetcher(fetcher);
     // grab the config widget, taking ownership
@@ -753,6 +775,7 @@ void ConfigDialog::readFetchConfig() {
     }
     kapp->processEvents();
   }
+  m_sourceListWidget->setUpdatesEnabled(true);
 
   if(m_sourceListWidget->count() == 0) {
     m_modifySourceBtn->setEnabled(false);
@@ -841,6 +864,7 @@ void ConfigDialog::saveFetchConfig() {
     configGroup.writeEntry("Name", item->data(Qt::DisplayRole).toString());
     configGroup.writeEntry("Type", int(item->fetchType()));
     configGroup.writeEntry("UpdateOverwrite", item->updateOverwrite());
+    configGroup.writeEntry("Uuid", item->uuid());
     cw->saveConfig(configGroup);
     item->setNewSource(false);
     // in case the ordering changed
@@ -860,16 +884,19 @@ void ConfigDialog::saveFetchConfig() {
 
   Config::self()->writeConfig();
 
-  QString s = m_sourceListWidget->currentItem() ? m_sourceListWidget->currentItem()->data(Qt::DisplayRole).toString() : QString();
   if(reloadFetchers) {
     Fetch::Manager::self()->loadFetchers();
     Controller::self()->updatedFetchers();
     // reload fetcher items if OK was not clicked
     // meaning apply was clicked
     if(!m_okClicked) {
+      QString currentSource;
+      if(m_sourceListWidget->currentItem()) {
+        currentSource = m_sourceListWidget->currentItem()->data(Qt::DisplayRole).toString();
+      }
       readFetchConfig();
-      if(!s.isEmpty()) {
-        QList<QListWidgetItem*> items = m_sourceListWidget->findItems(s, Qt::MatchExactly);
+      if(!currentSource.isEmpty()) {
+        QList<QListWidgetItem*> items = m_sourceListWidget->findItems(currentSource, Qt::MatchExactly);
         if(!items.isEmpty()) {
           m_sourceListWidget->setCurrentItem(items.first());
           m_sourceListWidget->scrollToItem(items.first());
@@ -927,7 +954,7 @@ void ConfigDialog::slotModifySourceClicked() {
   if(!cw) {
     // no config widget for this one
     // might be because support was compiled out
-    myDebug() << "no config widget for source" << item->data(Qt::DisplayRole);
+    myDebug() << "no config widget for source" << item->data(Qt::DisplayRole).toString();
     return;
   }
   FetcherConfigDialog dlg(item->data(Qt::DisplayRole).toString(), item->fetchType(), item->updateOverwrite(), cw, this);
@@ -986,6 +1013,16 @@ void ConfigDialog::slotMoveDownSourceClicked() {
   slotModified(); // toggle apply button
 }
 
+void ConfigDialog::slotSourceFilterChanged() {
+  m_sourceTypeCombo->setEnabled(m_cbFilterSource->isChecked());
+  const bool showAll = !m_sourceTypeCombo->isEnabled();
+  const int type = m_sourceTypeCombo->currentType();
+  for(int count = 0; count < m_sourceListWidget->count(); ++count) {
+    SourceListItem* item = static_cast<SourceListItem*>(m_sourceListWidget->item(count));
+    item->setHidden(!showAll && item->fetcher() && !item->fetcher()->canFetch(type));
+  }
+}
+
 void ConfigDialog::slotSelectedSourceChanged(QListWidgetItem* item_) {
   int row = m_sourceListWidget->row(item_);
   m_moveUpSourceBtn->setEnabled(row > 0);
@@ -993,9 +1030,16 @@ void ConfigDialog::slotSelectedSourceChanged(QListWidgetItem* item_) {
 }
 
 void ConfigDialog::slotNewStuffClicked() {
+#ifdef ENABLE_KNEWSTUFF3
+  KNS3::DownloadDialog dialog(QLatin1String("tellico-script.knsrc"), this);
+  dialog.exec();
+  {
+    KNS3::Entry::List entries = dialog.installedEntries();
+#else
   KNS::Engine engine(this);
   if(engine.init(QLatin1String("tellico-script.knsrc"))) {
     KNS::Entry::List entries = engine.downloadDialogModal(this);
+#endif
     if(!entries.isEmpty()) {
       Fetch::Manager::self()->loadFetchers();
       readFetchConfig();
@@ -1103,9 +1147,16 @@ void ConfigDialog::slotInstallTemplate() {
 }
 
 void ConfigDialog::slotDownloadTemplate() {
+#ifdef ENABLE_KNEWSTUFF3
+  KNS3::DownloadDialog dialog(QLatin1String("tellico-template.knsrc"), this);
+  dialog.exec();
+  {
+    KNS3::Entry::List entries = dialog.installedEntries();
+#else
   KNS::Engine engine(this);
   if(engine.init(QLatin1String("tellico-template.knsrc"))) {
     KNS::Entry::List entries = engine.downloadDialogModal(this);
+#endif
     if(!entries.isEmpty()) {
       loadTemplateList();
     }
