@@ -57,8 +57,8 @@ namespace {
   static const int SRU_MAX_RECORDS = 25;
 }
 
+using namespace Tellico;
 using Tellico::Fetch::SRUFetcher;
-using Tellico::Fetch::SRUConfigWidget;
 
 SRUFetcher::SRUFetcher(QObject* parent_)
     : Fetcher(parent_), m_job(0), m_MARCXMLHandler(0), m_MODSHandler(0), m_SRWHandler(0), m_started(false) {
@@ -80,10 +80,6 @@ SRUFetcher::~SRUFetcher() {
   m_SRWHandler = 0;
 }
 
-QString SRUFetcher::defaultName() {
-  return i18n("SRU Server");
-}
-
 QString SRUFetcher::source() const {
   return m_name.isEmpty() ? defaultName() : m_name;
 }
@@ -107,7 +103,6 @@ void SRUFetcher::readConfigHook(const KConfigGroup& config_) {
     m_path.prepend(QLatin1Char('/'));
   }
   m_format = config_.readEntry("Format", "mods");
-  m_fields = config_.readEntry("Custom Fields", QStringList());
 }
 
 void SRUFetcher::search() {
@@ -334,13 +329,6 @@ void SRUFetcher::slotComplete(KJob*) {
     return;
   }
 
-  const StringMap customFields = SRUFetcher::customFields();
-  for(StringMap::ConstIterator it = customFields.begin(); it != customFields.end(); ++it) {
-    if(!m_fields.contains(it.key())) {
-      coll->removeField(it.key());
-    }
-  }
-
   Data::EntryList entries = coll->entries();
   foreach(Data::EntryPtr entry, entries) {
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
@@ -350,7 +338,7 @@ void SRUFetcher::slotComplete(KJob*) {
   stop();
 }
 
-Tellico::Data::EntryPtr SRUFetcher::fetchEntry(uint uid_) {
+Tellico::Data::EntryPtr SRUFetcher::fetchEntryHook(uint uid_) {
   return m_entries[uid_];
 }
 
@@ -451,20 +439,28 @@ Tellico::Fetch::Fetcher::Ptr SRUFetcher::libraryOfCongress(QObject* parent_) {
                                      QLatin1String("voyager"), parent_));
 }
 
+QString SRUFetcher::defaultName() {
+  return i18n("SRU Server");
+}
+
+QString SRUFetcher::defaultIcon() {
+  return QLatin1String("network-workgroup"); // just to be different than z3950
+}
+
 // static
-Tellico::StringMap SRUFetcher::customFields() {
-  StringMap map;
-  map[QLatin1String("address")]  = i18n("Address");
-  map[QLatin1String("abstract")] = i18n("Abstract");
-  return map;
+Tellico::StringHash SRUFetcher::allOptionalFields() {
+  StringHash hash;
+  hash[QLatin1String("address")]  = i18n("Address");
+  hash[QLatin1String("abstract")] = i18n("Abstract");
+  return hash;
 }
 
 Tellico::Fetch::ConfigWidget* SRUFetcher::configWidget(QWidget* parent_) const {
-  return new SRUConfigWidget(parent_, this);
+  return new ConfigWidget(parent_, this);
 }
 
-SRUConfigWidget::SRUConfigWidget(QWidget* parent_, const SRUFetcher* fetcher_ /*=0*/)
-    : ConfigWidget(parent_) {
+SRUFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const SRUFetcher* fetcher_ /*=0*/)
+    : Fetch::ConfigWidget(parent_) {
   QGridLayout* l = new QGridLayout(optionsWidget());
   l->setSpacing(4);
   l->setColumnStretch(1, 10);
@@ -520,7 +516,7 @@ SRUConfigWidget::SRUConfigWidget(QWidget* parent_, const SRUFetcher* fetcher_ /*
   l->setRowStretch(++row, 1);
 
   // now add additional fields widget
-  addFieldsWidget(SRUFetcher::customFields(), fetcher_ ? fetcher_->m_fields : QStringList());
+  addFieldsWidget(SRUFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
 
   if(fetcher_) {
     m_hostEdit->setText(fetcher_->m_host);
@@ -531,7 +527,7 @@ SRUConfigWidget::SRUConfigWidget(QWidget* parent_, const SRUFetcher* fetcher_ /*
   KAcceleratorManager::manage(optionsWidget());
 }
 
-void SRUConfigWidget::saveConfig(KConfigGroup& config_) {
+void SRUFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
   QString s = m_hostEdit->text().trimmed();
   if(!s.isEmpty()) {
     config_.writeEntry("Host", s);
@@ -548,16 +544,14 @@ void SRUConfigWidget::saveConfig(KConfigGroup& config_) {
   if(!s.isEmpty()) {
     config_.writeEntry("Format", s);
   }
-  saveFieldsConfig(config_);
-  slotSetModified(false);
 }
 
-QString SRUConfigWidget::preferredName() const {
+QString SRUFetcher::ConfigWidget::preferredName() const {
   QString s = m_hostEdit->text();
   return s.isEmpty() ? SRUFetcher::defaultName() : s;
 }
 
-void SRUConfigWidget::slotCheckHost() {
+void SRUFetcher::ConfigWidget::slotCheckHost() {
   QString s = m_hostEdit->text();
   // someone might be pasting a full URL, check that
   if(s.indexOf(QLatin1Char(':')) > -1 || s.indexOf(QLatin1Char('/')) > -1) {
