@@ -124,7 +124,17 @@ void XMLFetcher::slotComplete(KJob* ) {
 
   parseData(data);
 
-  QString str = m_xsltHandler->applyStylesheet(XMLHandler::readXMLData(data));
+  const QString str = m_xsltHandler->applyStylesheet(XMLHandler::readXMLData(data));
+#if 0
+  myWarning() << "Remove debug from xmlfetcher.cpp";
+  QFile f2(QLatin1String("/tmp/test-tellico.xml"));
+  if(f2.open(QIODevice::WriteOnly)) {
+    QTextStream t(&f2);
+    t.setCodec("utf-8");
+    t << str;
+  }
+  f2.close();
+#endif
   Import::TellicoImporter imp(str);
   Data::CollPtr coll = imp.collection();
   if(!coll) {
@@ -133,6 +143,11 @@ void XMLFetcher::slotComplete(KJob* ) {
     return;
   }
 
+  if(m_limit < 1) {
+    myDebug() << "Limit < 1, changing to 1";
+    m_limit = 1;
+  }
+
   int count = 0;
   foreach(Data::EntryPtr entry, coll->entries()) {
     if(count >= m_limit) {
