@@ -64,10 +64,6 @@ YahooFetcher::~YahooFetcher() {
   m_xsltHandler = 0;
 }
 
-QString YahooFetcher::defaultName() {
-  return i18n("Yahoo! Audio Search");
-}
-
 QString YahooFetcher::source() const {
   return m_name.isEmpty() ? defaultName() : m_name;
 }
@@ -292,7 +288,7 @@ void YahooFetcher::getTracks(Tellico::Data::EntryPtr entry_) {
   u.addQueryItem(QLatin1String("albumid"), albumid);
 
 //  myDebug() << "url: " << u.url();
-  QDomDocument dom = FileHandler::readXMLFile(u, false /*no namespace*/, true /*quiet*/);
+  QDomDocument dom = FileHandler::readXMLDocument(u, false /*no namespace*/, true /*quiet*/);
   if(dom.isNull()) {
     myDebug() << "null dom returned";
     return;
@@ -375,6 +371,19 @@ Tellico::Fetch::FetchRequest YahooFetcher::updateRequest(Data::EntryPtr entry_)
   return FetchRequest();
 }
 
+QString YahooFetcher::defaultName() {
+  return i18n("Yahoo! Audio Search");
+}
+
+QString YahooFetcher::defaultIcon() {
+  return favIcon("http://www.yahoo.com");
+}
+
+Tellico::StringHash YahooFetcher::allOptionalFields() {
+  StringHash hash;
+  return hash;
+}
+
 Tellico::Fetch::ConfigWidget* YahooFetcher::configWidget(QWidget* parent_) const {
   return new YahooFetcher::ConfigWidget(parent_, this);
 }
