@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright (C) 2010 Robby Stephenson <robby@periapsis.org>
+    Copyright (C) 2010-2011 Robby Stephenson <robby@periapsis.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -28,7 +28,6 @@
 #include "amazonfetchertest.moc"
 #include "qtest_kde.h"
 
-#include "../fetch/fetcherjob.h"
 #include "../fetch/amazonfetcher.h"
 #include "../collections/bookcollection.h"
 #include "../collections/musiccollection.h"
@@ -42,7 +41,7 @@
 
 QTEST_KDEMAIN( AmazonFetcherTest, GUI )
 
-AmazonFetcherTest::AmazonFetcherTest() : m_loop(this), m_hasConfigFile(false)
+AmazonFetcherTest::AmazonFetcherTest() : AbstractFetcherTest(), m_hasConfigFile(false)
     , m_config(QString::fromLatin1(KDESRCDIR)  + "/amazonfetchertest.config", KConfig::SimpleConfig) {
 }
 
@@ -90,7 +89,7 @@ void AmazonFetcherTest::initTestCase() {
 //  pacteDesLoups.insert(QLatin1String("format"), QLatin1String("PAL"));
 
   QHash<QString, QString> petitPrinceCN;
-  petitPrinceCN.insert(QLatin1String("title"), QString::fromUtf8("小王子"));
+  petitPrinceCN.insert(QLatin1String("title"), QString::fromUtf8("小王子(65周年纪念版)"));
   petitPrinceCN.insert(QLatin1String("author"), QString::fromUtf8("圣埃克絮佩里 (Saint-Exupery)"));
 
   m_fieldValues.insert(QLatin1String("practicalRdf"), practicalRdf);
@@ -116,16 +115,11 @@ void AmazonFetcherTest::testTitle() {
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::AmazonFetcher(this));
   fetcher->readConfig(cg, cg.name());
 
-  // don't use 'this' as job parent, it crashes
-  Tellico::Fetch::FetcherJob* job = new Tellico::Fetch::FetcherJob(0, fetcher, request);
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
 
-  job->start();
-  m_loop.exec();
+  QVERIFY(!results.isEmpty());
 
-  QVERIFY(!m_results.isEmpty());
-
-  Tellico::Data::EntryPtr entry = m_results.at(0);
+  Tellico::Data::EntryPtr entry = results.at(0);
   QHashIterator<QString, QString> i(m_fieldValues.value(resultName));
   while(i.hasNext()) {
     i.next();
@@ -134,10 +128,14 @@ void AmazonFetcherTest::testTitle() {
       QEXPECT_FAIL("CA video title", "CA video titles show music results for some reason", Continue);
     }
     QString result = entry->field(i.key()).toLower();
-    // CA and FR titles have edition info in the title
+    // several titles have edition info in the title
     if(collType == Tellico::Data::Collection::Video &&
+       i.key() == QLatin1String("title") &&
        (locale == QLatin1String("CA") ||
         locale == QLatin1String("FR") ||
+        locale == QLatin1String("ES") ||
+        locale == QLatin1String("CN") ||
+        locale == QLatin1String("IT") ||
         locale == QLatin1String("DE"))) {
       QVERIFY2(result.contains(i.value(), Qt::CaseInsensitive), i.key().toAscii());
     } else {
@@ -168,12 +166,11 @@ void AmazonFetcherTest::testTitle_data() {
                                  << static_cast<int>(Tellico::Data::Collection::Book)
                                  << QString::fromLatin1("Practical RDF")
                                  << QString::fromLatin1("practicalRdf");
-/*
   QTest::newRow("CN book title") << QString::fromLatin1("CN")
                                   << static_cast<int>(Tellico::Data::Collection::Book)
-                                  << QString::fromLatin1("小王子")
+                                  << QString::fromUtf8("小王子(65周年纪念版)")
                                   << QString::fromLatin1("petitPrinceCN");
-*/
+
   // a known bug is CA video titles result in music results, so only title matches
 //  QTest::newRow("CA video title") << QString::fromLatin1("CA")
 //                                  << static_cast<int>(Tellico::Data::Collection::Video)
@@ -183,7 +180,6 @@ void AmazonFetcherTest::testTitle_data() {
                                   << static_cast<int>(Tellico::Data::Collection::Video)
                                   << QString::fromLatin1("Le Pacte des Loups")
                                   << QString::fromLatin1("pacteDesLoups");
-/*
   QTest::newRow("ES video title") << QString::fromLatin1("ES")
                                   << static_cast<int>(Tellico::Data::Collection::Video)
                                   << QString::fromLatin1("Le Pacte des Loups")
@@ -192,7 +188,7 @@ void AmazonFetcherTest::testTitle_data() {
                                   << static_cast<int>(Tellico::Data::Collection::Video)
                                   << QString::fromLatin1("Le Pacte des Loups")
                                   << QString::fromLatin1("pacteDesLoups");
-*/
+
 }
 
 void AmazonFetcherTest::testIsbn() {
@@ -212,16 +208,11 @@ void AmazonFetcherTest::testIsbn() {
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::AmazonFetcher(this));
   fetcher->readConfig(cg, cg.name());
 
-  // don't use 'this' as job parent, it crashes
-  Tellico::Fetch::FetcherJob* job = new Tellico::Fetch::FetcherJob(0, fetcher, request);
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
 
-  job->start();
-  m_loop.exec();
+  QCOMPARE(results.size(), 2);
 
-  QCOMPARE(m_results.size(), 2);
-
-  Tellico::Data::EntryPtr entry = m_results.at(0);
+  Tellico::Data::EntryPtr entry = results.at(0);
   QHashIterator<QString, QString> i(m_fieldValues.value(resultName));
   while(i.hasNext()) {
     i.next();
@@ -271,16 +262,11 @@ void AmazonFetcherTest::testUpc() {
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::AmazonFetcher(this));
   fetcher->readConfig(cg, cg.name());
 
-  // don't use 'this' as job parent, it crashes
-  Tellico::Fetch::FetcherJob* job = new Tellico::Fetch::FetcherJob(0, fetcher, request);
-  connect(job, SIGNAL(result(KJob*)), this, SLOT(slotResult(KJob*)));
+  Tellico::Data::EntryList results = DO_FETCH(fetcher, request);
 
-  job->start();
-  m_loop.exec();
+  QVERIFY(!results.isEmpty());
 
-  QVERIFY(!m_results.isEmpty());
-
-  Tellico::Data::EntryPtr entry = m_results.at(0);
+  Tellico::Data::EntryPtr entry = results.at(0);
   QHashIterator<QString, QString> i(m_fieldValues.value(resultName));
   while(i.hasNext()) {
     i.next();
@@ -339,8 +325,3 @@ void AmazonFetcherTest::testUpc_data() {
                                 << QString::fromLatin1("5050582560985")
                                 << QString::fromLatin1("pacteDesLoups");
 }
-
-void AmazonFetcherTest::slotResult(KJob* job_) {
-  m_results = static_cast<Tellico::Fetch::FetcherJob*>(job_)->entries();
-  m_loop.quit();
-}
