@@ -94,7 +94,7 @@ bool PilotDBExporter::exec() {
   // except that only one field of type NOTE
   bool hasNote = false;
   Data::FieldList outputFields; // not all fields will be output
-  foreach(Data::FieldPtr fIt, coll->fields()) {
+  foreach(Data::FieldPtr fIt, fields()) {
     switch(fIt->type()) {
       case Data::Field::Choice:
         // the charSeparator is actually defined in DB.h
@@ -198,7 +198,7 @@ bool PilotDBExporter::exec() {
         value.remove(tags);
       }
       // the number of fields in the record must match the number of fields in the database
-      record.appendField(PilotDB::string2field(db.field_type(i),
+      record.appendField(PilotDatabase::string2field(db.field_type(i),
                          value.isEmpty() ? std::string() : codec->fromUnicode(value).data()));
       ++i;
     }
@@ -206,7 +206,7 @@ bool PilotDBExporter::exec() {
     db.appendRecord(record);
   }
 
-  PilotDB pdb;
+  PilotDatabase pdb;
   db.outputPDB(pdb);
 
   return FileHandler::writeDataURL(url(), pdb.data(), options() & Export::ExportForce);
